==> pan-0.12.1.tar.gz: pan-0.12.1/pan/prefs.h <==
/*
 * Pan - A Newsreader for X
 * Copyright (C) 1999, 2000, 2001  Pan Development Team <pan@rebelbase.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#ifndef __PREFS_H__
#define __PREFS_H__

/**
*** Global Variables
**/

extern gboolean                remove_failed_tasks;
extern gboolean                single_click_selects;
extern gboolean                header_pane_is_threaded;
extern gboolean                show_group_pane;
extern gboolean                show_header_pane;
extern gboolean                show_body_pane;
extern gboolean                text_use_fixed_font;
extern gboolean                text_window_smooth_scrolling;
extern gint                    text_window_smooth_scrolling_speed;
extern gboolean                fetch_new_on_startup;
extern gboolean                fetch_new_and_bodies_on_startup;
extern gboolean                fetch_new_on_group_load;
extern gboolean                expand_all_threads_by_default;
extern gboolean                hide_mpart_child_nodes;
extern gboolean                pan_mute;
extern gchar                 * thread_date_format;
extern gchar                 * body_date_format;
extern gchar                 * grouplist_font;
extern gchar                 * thread_normal_font;
extern gchar                 * thread_new_replies_font;
extern gchar                 * message_body_font;
extern gchar                 * message_body_font_fixed;
extern gchar                 * external_web_browser;
extern gchar                 * external_editor;
extern gchar                 * mail_server_address;
extern gchar                 * layout_str;
extern gint                    mail_server_port;
extern gint                    wrap_column;
extern gboolean                collapse_group_names;
extern gboolean                use_system_fg;
extern gboolean                use_system_bg;

extern gchar *                 newsrc_filename;
extern gboolean                newsrc_do_port;
extern gboolean                newsrc_port_subscribed_only;



/** 
*** Function Prototypes
**/

extern void prefs_spawn_to_news_servers      (void);

extern void prefs_spawn_to_news_connections  (void);

extern void prefs_spawn                      (void);

extern void prefs_init                       (void);

#endif /* __PREFS_H__ */

==> pan-0.13.0.90.tar.gz: pan-0.13.0.90/pan/prefs.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * Pan - A Newsreader for Gtk+
 * Copyright (C) 2002  Charles Kerr <charles@rebelbase.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __PREFS_H__
#define __PREFS_H__

/**
*** Global Variables
**/

extern gboolean                remove_failed_tasks;
extern gboolean                single_click_selects;
extern gboolean                header_pane_is_threaded;
extern gboolean                show_group_pane;
extern gboolean                show_header_pane;
extern gboolean                show_body_pane;
extern gboolean                text_use_fixed_font;
extern gboolean                text_window_smooth_scrolling;
extern int                     text_window_smooth_scrolling_speed;
extern gboolean                fetch_new_on_startup;
extern gboolean                fetch_new_and_bodies_on_startup;
extern gboolean                fetch_new_on_group_load;
extern gboolean                expand_all_threads_by_default;
extern gboolean                hide_mpart_child_nodes;
extern gboolean                pan_mute;
extern char                  * thread_date_format;
extern char                  * group_pane_font;
extern char                  * header_pane_font;
extern char                  * message_body_font;
extern char                  * message_body_font_fixed;
extern char                  * external_web_browser;
extern char                  * external_editor;
extern char                  * mail_server_address;
extern char                  * layout_str;
extern int                     mail_server_port;
extern int                     wrap_column;
extern gboolean                collapse_group_names;
#if 0
extern gboolean                use_system_fg;
extern gboolean                use_system_bg;
#endif
extern gboolean                do_spellcheck;



/** 
*** Function Prototypes
**/

void prefs_spawn                         (void);

void prefs_init                          (void);

void show_group_substitution_help_dialog (gpointer window);

#endif /* __PREFS_H__ */
